### analysis script for Experiment 2 Nijveld, ten Bosch & Ernestus (under review)
### ran under R version 3.4.1
#### contains:  description of participants
####            description of materials (word duration incl. plots)
####            analysis of **accuracy**
####                -description of average error rates
####                -final model (incl. discussion of slopes)
####                -competing model 
####                -additional analysis: cognates
####                -additional analysis: proficiency
####            analysis of **RT**
####                -description of average RTs
####                -final model (incl. discussion of slopes)
####                -competing model
####                -additional analysis: cognates
####                -additional analysis: proficiency
####                -code to generate barplots RT + helper functions for plots


###

library(lme4)

d=read.table('ds_EXP2_reduction.txt',T)
colnames(d)
# [1] "subject"          "trial"            "sub_experiment"   "lexdec_part"      "handedness"      
# [6] "correctresponse"  "withinPartTrial"  "stimulus"         "reduced"          "word.nonword"    
# [11] "response"         "RT"               "correctness"      "gender"           "age"             
# [16] "nativeLanguage"   "levelENlistening" "word"             "count.per.mil"    "X2log"           
# [21] "wavduration"      "vowel.duration"   "lag"              "correctPrime"     "RTprime"         
# [26] "reduced_prime"    "RTprev"           "score_lextale"    "stimtype"         "prime.target"    
# [31] "condition"   


################### PARTICIPANTS

exclude = c("Cs13", "Ns2","Ns7","Ns13","Ns56","Ms11","Ms12","Ms13","Ms14","Ms32", "Ms68") # excluded a priori because of:
# deviant nativeLanguage = Cs13, Ns13
# experimental error/technical issues (e.g. ran without headphones) = Ns2, Ns7, Ns56, Ms11, Ms12, Ms13, Ms14
# reported hearing issues = Ms32, Ms68
d1 = d[!is.element(d$subject, exclude),]
d1=droplevels(d1)

### participant characteristics per participant group
# Dutch (Nijmegen)
dN = d1[d1$nativeLanguage=="dutch",] 
ppN = unique(dN[, c("subject", "handedness", "score_lextale", "age", "gender","levelENlistening", "nativeLanguage")]) 
# subject   handedness score_lextale         age           gender   levelENlistening nativeLanguage
# Ns1    : 1   left : 2   Min.   : 48.75   Min.   :18.00   female:29   Min.   :3.000    dutch  :40    
# Ns10   : 1   right:38   1st Qu.: 63.75   1st Qu.:19.75   male  :11   1st Qu.:4.000    english: 0    
# Ns11   : 1              Median : 71.88   Median :20.00               Median :5.000    spanish: 0    
# Ns12   : 1              Mean   : 72.91   Mean   :20.32               Mean   :4.675                  
# Ns14   : 1              3rd Qu.: 80.31   3rd Qu.:21.00               3rd Qu.:5.000                  
# Ns15   : 1              Max.   :100.00   Max.   :25.00               Max.   :6.000                  
# (Other):34        
round(sd(ppN$levelENlistening),1) # 0.7
round(sd(ppN$score_lextale)) # 12

# English (Cambridge)
dC = d1[d1$nativeLanguage=="english",] 
ppC = unique(dC[, c("subject", "handedness", "score_lextale", "age", "gender","nativeLanguage")]) 
# subject   handedness score_lextale      age           gender   nativeLanguage
# Cs1    : 1   left : 5   Min.   : NA   Min.   :18.00   female:21   dutch  : 0    
# Cs10   : 1   right:29   1st Qu.: NA   1st Qu.:20.00   male  :13   english:34    
# Cs11   : 1              Median : NA   Median :21.50               spanish: 0    
# Cs12   : 1              Mean   :NaN   Mean   :21.74                             
# Cs14   : 1              3rd Qu.: NA   3rd Qu.:22.75                             
# Cs15   : 1              Max.   : NA   Max.   :28.00                             
# (Other):28              NA's   :34                               

# Spanish (Madrid)
dM = d1[d1$nativeLanguage=="spanish",] 
ppM = unique(dM[, c("subject", "handedness", "score_lextale", "age", "gender","levelENlistening","nativeLanguage")]) 
summary(ppM)
# subject   handedness score_lextale        age           gender   levelENlistening nativeLanguage
# Ms1    : 1   left : 0   Min.   :43.75   Min.   :19.00   female:16   Min.   :2.0      dutch  : 0    
# Ms10   : 1   right:40   1st Qu.:60.00   1st Qu.:20.75   male  :24   1st Qu.:3.0      english: 0    
# Ms15   : 1              Median :67.50   Median :21.50               Median :4.0      spanish:40    
# Ms16   : 1              Mean   :66.56   Mean   :21.73               Mean   :3.8                    
# Ms17   : 1              3rd Qu.:71.56   3rd Qu.:23.00               3rd Qu.:5.0                    
# Ms18   : 1              Max.   :92.50   Max.   :26.00               Max.   :6.0                    
# (Other):34                                                                                         
round(sd(ppM$levelENlistening),1) # 1.1
round(sd(ppM$score_lextale)) # 10

nn=rbind(ppM,ppN)
# is lextale scores significantly different between NL & SP groups?

lm=lm(score_lextale~nativeLanguage,data=nn)
summary(lm)
# Call:
#   lm(formula = score_lextale ~ nativeLanguage, data = nn)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -24.1563  -7.8359   0.2656   5.9375  27.0937 
# 
#   Coefficients:
#   Estimate Std. Error t value Pr(>|t|)    
#   (Intercept)             72.906      1.718   42.43   <2e-16 ***
#   nativeLanguagespanish   -6.344      2.430   -2.61   0.0108 *  
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 10.87 on 78 degrees of freedom
# Multiple R-squared:  0.08034,	Adjusted R-squared:  0.06855 
# F-statistic: 6.814 on 1 and 78 DF,  p-value: 0.01084



######################## MATERIALS

### wav plots (reduced + unreduced 'cassette')
library(tuneR)
## full (unreduced) wav
f = readWave('cassette_f_t_4_3.wav')
s1=f@left # extract filled channel
# convert sound array to floating point values ranging from -1 to 1 as follows 
s1=s1/2^(f@bit-1) 
# a time representation of the sound can be obtained by plotting the pressure values against the time axis. 
# create an array containing the time points first
timeArray1 <- (0:(25252-1)) / f@samp.rate
timeArray1 <- timeArray1 * 1000 #scale to milliseconds
# keep this timeArray
## reduced wav 
r = readWave('c+set_r_t_11.wav')
s2=r@left # extract filled channel
# convert sound array to floating point values ranging from -1 to 1
s2=s2/2^(r2@bit-1) 
timeArray2 <- (0:(21908-1)) / r@samp.rate
timeArray2 <- timeArray2 * 1000 #scale to milliseconds
## plot
par(mfrow=c(2,1))
par(oma = c(4, 3, 0, 0)) 
par(mar = c(1, 2, 2, 2)+0.1) 
fullplot = plot(timeArray1, s1, type='l', col='black', xlab='', ylab='', cex.lab=1.2, cex.axis=1.2, cex.main=1.2, cex.sub=1.2, xlim=c(0,560), ylim=c(-0.35, 0.4)) 
reducedplot = plot(timeArray2, s2, type='l', col='black', xlab='', ylab='', cex.lab=1.2, cex.axis=1.2, cex.main=1.2, cex.sub=1.2, xlim=c(0,560), ylim=c(-0.35, 0.4))
axis(side=2, labels = FALSE)  
mtext('Time (ms)', side = 1, outer = TRUE, line = 2, cex=1.5)
mtext('Amplitude', side = 2, outer = TRUE, line = 1, cex=1.5) 

### word durations
# unreduced primes
unreduced_primes=unique(d1[d1$prime.target=="prime"&d1$reduced=="unreduced",]$wavduration)
unreduced_primes=unreduced_primes[!is.na(unreduced_primes)]
mean(unreduced_primes)
# [1] 627.931
sd(unreduced_primes)
# [1] 75.40696

# reduced_primes
reduced_primes = unique(d1[d1$prime.target=="prime"&d1$reduced=="reduced",]$wavduration)
reduced_primes=reduced_primes[!is.na(reduced_primes)]

# targets (all reduced)
targets = unique(d1[d1$prime.target=="target",]$wavduration)
targets=targets[!is.na(targets)]
all_reduced = c(reduced_primes, targets)
mean(all_reduced)
#[1] 527.5932
sd(all_reduced)
#[1] 68.40879

## boxplots word durations 
par(mfrow=c(1,3))
par(oma = c(2, 3.5, 1, 2)) # make room (i.e. the 4's) for the overall x and y axis titles
boxplot(unreduced_primes,ylim=c(400,800), cex.axis=1.5)
boxplot(reduced_primes,ylim=c(400,800),yaxt="n")
axis(side=2, labels = FALSE)  
boxplot(targets,ylim=c(400,800),yaxt="n")
axis(side=2, labels = FALSE)  
mtext('Word duration (ms)', side = 2, outer = TRUE, line = 1.8, cex=1.0)  
mtext('Unreduced primes', side = 1, outer=T, at=0.17) 
mtext('Reduced primes', side = 1, outer=T, at=0.50) 
mtext('Reduced targets', side = 1, outer=T, at=0.84)

### can vowel duration predict word duration of the experimental words?
d2=d1[d1$stimtype=="ld_experimental_real",]
w = unique(d2[, c("stimulus", "reduced", "wavduration", "vowel.duration", "prime.target")]) 
w$durminvowel = w$wavduration-w$vowel.duration
lm=lm(formula = durminvowel ~ vowel.duration, data = w)
# Call:
#   lm(formula = durminvowel ~ vowel.duration, data = w)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -121.437  -57.195   -7.108   46.966  201.375 
# 
# Coefficients:
#   Estimate Std. Error t value Pr(>|t|)    
#   (Intercept)    493.3758    16.6254  29.676   <2e-16 ***
#   vowel.duration   0.9732     0.4073   2.389    0.019 *  
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 76.8 on 89 degrees of freedom
# Multiple R-squared:  0.06028,	Adjusted R-squared:  0.04972 
# F-statistic: 5.709 on 1 and 89 DF,  p-value: 0.01899



################### RESULTS AND DISCUSSION

#### participant and word exclusion if exceeding 2.5 sd from grand mean
# participants
d2=d1[d1$sub_experiment=="auditoryLD"&d1$stimtype=="ld_experimental_real"&d1$prime.target=="target",]
d2=droplevels(d2)

correct = table(d2$subject,d2$correctness)
new = data.frame(correct)
subsetnew = new[new$Var2 == "incorrect",]
m = mean(subsetnew$Freq)
sd = sd(subsetnew$Freq)
exclude = subsetnew[subsetnew$Freq > m+(2.5*sd),]
# Var1      Var2 Freq
# 166 Ms29 incorrect   12
# 171 Ms34 incorrect   12
# 173 Ms36 incorrect   14

# words
correct = table(d2$word,d2$correctness)
new = data.frame(correct)
subsetnew = new[new$Var2 == "incorrect",]
m = mean(subsetnew$Freq) 
sd = sd(subsetnew$Freq) 
exclude = subsetnew[subsetnew$Freq > m+(2.5*sd),]
# Var1      Var2 Freq
# 57 saloon incorrect   70

# exclude these participants and this word:
d3=d2[d2$subject!="Ms29"&d2$subject!="Ms34"&d2$subject!="Ms36",]
d4=d3[d3$word!="saloon",]



#### ACCURACY ANALYSIS ######

##### exclude targets with incorrect primes (percentage exclusion reported below)
d5=d4[d4$correctPrime=="correct",]

# percentage excluded data
round(100*(nrow(d4)-nrow(d5))/nrow(d4)) # 10%
setdiffDF <- function(A, B){
  f <- function(A, B)
    A[!duplicated(rbind(B, A))[nrow(B) + 1:nrow(A)], ]
  df1 <- f(A, B)
  df2 <- f(B, A)
  rbind(df1, df2)
}
a=setdiffDF(d4, d5)
summary(a$nativeLanguage)
# dutch english spanish 
# 96      61     171 

### error rates on remaining data
# overall
dxtabs = xtabs(~correctness, data=d5)
round(100 * prop.table(dxtabs))
# correctness
# correct incorrect 
# 96         4 

# per participant group
dxtabs2 = xtabs(~correctness+nativeLanguage, data=d5)
round(100 * prop.table(dxtabs2,2))
#             nativeLanguage
# correctness dutch english spanish
# correct      96      97      94
# incorrect     4       3       6

# report SDs too
# overall
correct_subj = data.frame(table(d5$subject,d5$correctness))
correct_subj2 = correct_subj[correct_subj$Var2 == "incorrect",]
sd = sd(correct_subj2$Freq) 
round(sd/29*100) 
# subsets
# English
dE=d5[d5$nativeLanguage=="english",]
dE=droplevels(dE)
correct_subj = data.frame(table(dE$subject,dE$correctness))
correct_subj2 = correct_subj[correct_subj$Var2 == "incorrect",]
sd = sd(correct_subj2$Freq) 
round(sd/29*100) # 3
# Dutch
dD=d5[d5$nativeLanguage=="dutch",]
dD=droplevels(dD)
correct_subj = data.frame(table(dD$subject,dD$correctness))
correct_subj2 = correct_subj[correct_subj$Var2 == "incorrect",]
sd = sd(correct_subj2$Freq) 
round(sd/29*100) # 4
# Spanish
dS=d5[d5$nativeLanguage=="spanish",]
dS=droplevels(dS)
correct_subj = data.frame(table(dS$subject,dS$correctness))
correct_subj2 = correct_subj[correct_subj$Var2 == "incorrect",]
sd = sd(correct_subj2$Freq) 
round(sd/29*100) # 4

##
d5$nativeLanguage=relevel(d5$nativeLanguage, "english")
d5$groupcontrast=d5$nativeLanguage
d5 = droplevels(d5)
contrasts(d5$groupcontrast) = rbind(c(2/3, 0), c(-1/3, 1/2), c(-1/3, -1/2)) # helmert coding
contrasts(d5$groupcontrast)
#             [,1]  [,2]
# english  0.6666667  0.0
# dutch   -0.3333333  0.5
# spanish -0.3333333 -0.5

d5$logwavduration=log(d5$wavduration)

# with "correctness" variable, level "correct" is on intercept because earlier in alphabet than "incorrect"
d5$mycorr = (d5$correctness == "correct")+0 # new variable for easier interpretation (gives opposite sign)
d5$condition=relevel(d5$condition, 'variant_mismatch')

### accuracy models testing for interaction + simple effects of interest (reported in-text)
# interaction:
d5.glmer1 = glmer(correctness ~ groupcontrast * condition + (1|subject) + (1|word), data = d5, family = "binomial") 
# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                           -3.78977    0.31602 -11.992   <2e-16 ***
#   groupcontrast1                      -0.31771    0.32842  -0.967    0.333    
# groupcontrast2                        -0.11572    0.34465  -0.336    0.737    
# conditionvariant_match                -0.09991    0.20895  -0.478    0.633    # n.s.
# groupcontrast1:conditionvariant_match -0.71159    0.48531  -1.466    0.143    # n.s.
# groupcontrast2:conditionvariant_match -0.68898    0.45171  -1.525    0.127    # n.s.
# -> same model with "mycorr" does not converge, so values from model above with opposite sign are reported (OK. louis, in-text) (current table A2-3)

# interaction + simple effect of condition not significant;
# model w/ group as simple effect (final model)
d5.glmer4_final = glmer(mycorr ~ groupcontrast  + (1|subject) + (1|word), data = d5, family = "binomial") 
# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   3.8035     0.2966  12.825   <2e-16 ***
#   group1        0.6263     0.2690   2.328   0.0199 * (in-text)      
#   group2        0.4429     0.2667   1.661   0.0967 . (in-text)


###########################
### louis: try to plug in lag, logwavduration, trial

d=read.table('ds_EXP2_reduction.txt',T)
exclude = c("Cs13", "Ns2","Ns7","Ns13","Ns56","Ms11","Ms12","Ms13","Ms14","Ms32", "Ms68") # excluded a priori because of: # deviant nativeLanguage = Cs13, Ns13 # experimental error/technical issues (e.g. ran without headphones) = Ns2, Ns7, Ns56, Ms11, Ms12, Ms13, Ms14 # reported hearing issues = Ms32, Ms68
d1 = d[!is.element(d$subject, exclude),]
d1=droplevels(d1)
d2=d1[d1$stimtype=="ld_experimental_real",]
#### participant and word exclusion if exceeding 2.5 sd from grand mean
# participants
d2=d1[d1$sub_experiment=="auditoryLD"&d1$stimtype=="ld_experimental_real"&d1$prime.target=="target",]
d2=droplevels(d2)
# exclude these participants and this word:
d3=d2[d2$subject!="Ms29"&d2$subject!="Ms34"&d2$subject!="Ms36",]
d4=d3[d3$word!="saloon",]
##### exclude targets with incorrect primes (percentage exclusion reported below)
d5=d4[d4$correctPrime=="correct",]
##
d5$nativeLanguage=relevel(d5$nativeLanguage, "english")
d5$groupcontrast=d5$nativeLanguage
d5 = droplevels(d5)
contrasts(d5$groupcontrast) = rbind(c(2/3, 0), c(-1/3, 1/2), c(-1/3, -1/2)) # helmert coding
d5$logwavduration=log(d5$wavduration)
d5$mycorr = (d5$correctness == "correct")+0 # new variable for easier interpretation (gives opposite sign)
d5$condition=relevel(d5$condition, 'variant_mismatch')

# previous model: d5.glmer1 = glmer(correctness ~ groupcontrast * condition + (1|subject) + (1|word), data = d5, family = "binomial") 
d5.glmer1B = glmer(correctness ~ groupcontrast * condition +trial + logwavduration + X2log + + (1|subject) + (1|word), data = d5, family = "binomial") # fails to converge
d5.glmer1B = glmer(correctness ~ groupcontrast * condition + logwavduration + X2log + + (1|subject) + (1|word), data = d5, family = "binomial") # fails
d5.glmer1B = glmer(correctness ~ groupcontrast * condition + logwavduration + (1|subject) + (1|word), data = d5, family = "binomial") # fails
d5.glmer1B = glmer(correctness ~ groupcontrast * condition + X2log + (1|subject) + (1|word), data = d5, family = "binomial") # fails
d5.glmer1B = glmer(correctness ~ groupcontrast * condition + lag + (1|subject) + (1|word), data = d5, family = "binomial") # fails
d5.glmer1B = glmer(correctness ~ groupcontrast * condition + trial + (1|subject) + (1|word), data = d5, family = "binomial") # converges
Random effects:
 Groups  Name        Variance Std.Dev.
 subject (Intercept) 0.3925   0.6265  
 word    (Intercept) 1.5355   1.2392  
Number of obs: 2891, groups:  subject, 111; word, 29

Fixed effects:
                                       Estimate Std. Error z value Pr(>|z|)    
(Intercept)                           -4.466948   0.686473  -6.507 7.66e-11 ***
groupcontrast1                        -0.314202   0.328270  -0.957    0.338    
groupcontrast2                        -0.111390   0.344875  -0.323    0.747    
conditionvariant_match                -0.088389   0.209489  -0.422    0.673    
trial                                  0.006207   0.005506   1.127    0.260    
groupcontrast1:conditionvariant_match -0.729557   0.486483  -1.500    0.134    
groupcontrast2:conditionvariant_match -0.700794   0.452588  -1.548    0.122    




########################### end of intermezzo


# alternative model testing for condition as simple effect 
d5.glmer5 = glmer(mycorr ~ condition  + (1|subject) + (1|word), data = d5, family = "binomial") 
# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
#   (Intercept)              3.7878     0.3117   12.15   <2e-16 ***
#   conditionvariant_match   0.0119     0.1979    0.06    0.952        # n.s.

### SLOPES on final model (with just simple effect of group)
# group by word -- singular fit error
d5.glmer4a = glmer(mycorr ~ groupcontrast + (1|subject) + (1|word) + (0+groupcontrast|word), data = d5, family = "binomial") 

# variant match by word -- convergence error
d5.glmer4b = glmer(mycorr ~ groupcontrast + (1|subject) + (1|word) + (0+condition|word), data = d5, family = "binomial") 

# variant match by pp -- singular fit error
d5.glmer4c = glmer(mycorr ~ groupcontrast + (1|subject) + (1|word) + (0+condition|subject), data = d5, family = "binomial") 


##############################
##### to run the 'complete' full model with Trials and the interaction Variant match x Listener group, the following is the preaamble:

d=read.table('ds_EXP2_reduction.txt',T)
exclude = c("Cs13", "Ns2","Ns7","Ns13","Ns56","Ms11","Ms12","Ms13","Ms14","Ms32", "Ms68") # excluded a priori because of:
# deviant nativeLanguage = Cs13, Ns13 # experimental error/technical issues (e.g. ran without headphones) = Ns2, Ns7, Ns56, Ms11, Ms12, Ms13, Ms14 # reported hearing issues = Ms32, Ms68
d1 = d[!is.element(d$subject, exclude),]
d1=droplevels(d1)
d2=d1[d1$sub_experiment=="auditoryLD"&d1$stimtype=="ld_experimental_real"&d1$prime.target=="target",]
d2=droplevels(d2) 
d3=d2[d2$subject!="Ms29"&d2$subject!="Ms34"&d2$subject!="Ms36",]
d4=d3[d3$word!="saloon",]
d5=d4[d4$correctPrime=="correct",]
d5$nativeLanguage=relevel(d5$nativeLanguage, "english")
d5$groupcontrast=d5$nativeLanguage
d5 = droplevels(d5)
contrasts(d5$groupcontrast) = rbind(c(2/3, 0), c(-1/3, 1/2), c(-1/3, -1/2)) # helmert coding
d5$logwavduration=log(d5$wavduration)
# with "correctness" variable, level "correct" is on intercept because earlier in alphabet than "incorrect"
d5$mycorr = (d5$correctness == "correct")+0 # new variable for easier interpretation (gives opposite sign)
d5$condition=relevel(d5$condition, 'variant_mismatch')

##############################

### competing accuracy model
d5.glmer_comp = glmer(mycorr ~ groupcontrast + condition + trial +  (1|subject) + (1|word), data = d5, family = "binomial") 
# Random effects:
#   Groups  Name        Variance Std.Dev.
# subject (Intercept) 0.3666   0.6055  
# word    (Intercept) 1.5019   1.2255  
# Number of obs: 2891, groups:  subject, 111; word, 29
# 
# Fixed effects: (old table A2-3)
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)             4.425443   0.681584   6.493 8.42e-11 ***
# groupcontrast1          0.630298   0.268510   2.347   0.0189 *  
# groupcontrast2          0.444186   0.266059   1.669   0.0950 . 
# conditionvariant_match -0.007605   0.198598  -0.038   0.9695  
# trial                  -0.005730   0.005482  -1.045   0.2959    
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1


d5.glmer_comp2 = glmer(mycorr ~ groupcontrast * condition + trial +  (1|subject) + (1|word), data = d5, family = "binomial") 
# this fails to converge
d5.glmer_comp3 = glmer(mycorr ~ groupcontrast * condition +  (1|subject) + (1|word), data = d5, family = "binomial") 

Fixed effects:
                                      Estimate Std. Error z value Pr(>|z|)    
(Intercept)                            3.78986    0.31608  11.990   <2e-16 ***
groupcontrast1                         0.31775    0.32843   0.967    0.333    
groupcontrast2                         0.11575    0.34465   0.336    0.737    
conditionvariant_match                 0.09989    0.20895   0.478    0.633    
groupcontrast1:conditionvariant_match  0.71160    0.48534   1.466    0.143    
groupcontrast2:conditionvariant_match  0.68900    0.45173   1.525    0.127    





# relevel condition
d5$condition_rel=relevel(d5$condition, 'variant_match')
d5.glmer_comp_rel = glmer(mycorr ~ groupcontrast + condition_rel + trial +  (1|subject) + (1|word), data = d5, family = "binomial") 
# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                    4.417729   0.670117   6.592 4.33e-11 ***
# groupcontrast1                 0.630282   0.268509   2.347   0.0189 *  
# groupcontrast2                 0.444193   0.266061   1.670   0.0950 .  
# condition_relvariant_mismatch  0.007697   0.198599   0.039   0.9691    
# trial                         -0.005730   0.005482  -1.045   0.2959   


### additional accuracy analysis: proficiency
## Dutch group has higher LexTALE scores and is bigger in size. Cut out best-performing Dutch and worst-performing Spanish 
# until equal group sizes and LexTALE scores are reached. include all English participants too.
cl=d5[d5$nativeLanguage=="english"|d5$nativeLanguage=="dutch"&d5$score_lextale<=85|d5$nativeLanguage=="spanish"&d5$score_lextale>=55,]

pp = unique(cl[, c("subject","nativeLanguage", "score_lextale")])
# subject   nativeLanguage score_lextale  
# Cs1    : 1   english:34     Min.   :48.75  
# Cs10   : 1   dutch  :33     1st Qu.:62.50  
# Cs11   : 1   spanish:33     Median :68.75  
# Cs12   : 1                  Mean   :69.11  
# Cs14   : 1                  3rd Qu.:74.69  
# Cs15   : 1                  Max.   :92.50  
# (Other):94                  NA's   :34     
tapply(pp$score_lextale,pp$nativeLanguage,mean)
# english    dutch  spanish 
# NA 69.20455 69.01515 
tapply(pp$score_lextale,pp$nativeLanguage,sd)
# english    dutch  spanish 
# NA 8.942187 8.759802 

lm=lm(score_lextale~nativeLanguage,data=pp)
summary(lm)
# Call:
#   lm(formula = score_lextale ~ nativeLanguage, data = pp)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -20.4545  -6.6572  -0.2652   5.6723  23.4848 
# 
# Coefficients:
#   Estimate Std. Error t value Pr(>|t|)    
#   (Intercept)            69.2045     1.5408  44.913   <2e-16 ***
#   nativeLanguagespanish  -0.1894     2.1791  -0.087    0.931    
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 8.851 on 64 degrees of freedom
# (34 observations deleted due to missingness)
# Multiple R-squared:  0.000118,	Adjusted R-squared:  -0.01551 
# F-statistic: 0.007554 on 1 and 64 DF,  p-value: 0.931

# run accuracy model testing for predictors of interest on this subset
cl.glmer3  = glmer(mycorr ~ groupcontrast * condition  + (1|subject) + (1|word), data = cl, family = "binomial")
# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                           3.756640   0.323543  11.611   <2e-16 ***
#   groupcontrast1                        0.409256   0.334812   1.222    0.222    
# groupcontrast2                        0.001105   0.364836   0.003    0.998    
# conditionvariant_match                0.125840   0.215478   0.584    0.559    
# groupcontrast1:conditionvariant_match 0.656989   0.491977   1.335    0.182    
# groupcontrast2:conditionvariant_match 0.719909   0.479067   1.503    0.133    

# additional accuracy analysis: cognates (on Dutch & Spanish data)
# Dutch
cognateD=c("balloon","banana","career", "cassette", "cement", "committee", 
           "debate", "defect","defence","domain","guitar","machine","parade",
           "police","safari","salami","saloon","tobacco","tomato")
d5$cognateD=F
d5[is.element(d5$word, cognateD),]$cognateD=T
du=d5[d5$nativeLanguage=="dutch",]
du.glmer3  = glmer(mycorr ~ cognateD * condition  + (1|subject) + (1|word), data = du, family = "binomial")
# Fixed effects: (in-text)
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                          4.128634   0.613268   6.732 1.67e-11 ***
# cognateDTRUE                        -0.704052   0.677411  -1.039    0.299    
# conditionvariant_match              -0.004699   0.600088  -0.008    0.994    
# cognateDTRUE:conditionvariant_match  0.321766   0.726092   0.443    0.658  

# Spanish
cognateSP=c("career", "cassette", "cement","collapse","committee", 
            "debate","decline", "defect","defence","design","divorce","domain","guitar","machine","parade",
            "police","potato","safari","salami","saloon","surprise","tobacco","tomato")
d5$cognateSP=F
d5[is.element(d5$word, cognateSP),]$cognateSP=T
sp=d5[d5$nativeLanguage=="spanish",]
sp.glmer3  = glmer(mycorr ~ cognateSP * condition  + (1|subject) + (1|word), data = sp, family = "binomial")
# Fixed effects:
#   Estimate Std. Error z value Pr(>|z|)    
# (Intercept)                           3.53927    0.66488   5.323 1.02e-07 ***
#   cognateSPTRUE                       0.05448    0.70740   0.077    0.939    
# conditionvariant_match               -0.49318    0.58243  -0.847    0.397    
# cognateSPTRUE:conditionvariant_match -0.05303    0.68373  -0.078    0.938    


####################### additional analysis, louis


#### review round 3: rev 3 asks about whether the task in part 2 is something different from lexdec. This may imply that the RTs on the real words in part 1 differ significantly from the RTs on the non-repeated words in part 2 (we did the same for experiment 1)

# first we redo the preamble


library(lme4)

d=read.table('ds_EXP2_reduction.txt',T)
colnames(d)
# [1] "subject"          "trial"            "sub_experiment"   "lexdec_part"      "handedness"      
# [6] "correctresponse"  "withinPartTrial"  "stimulus"         "reduced"          "word.nonword"    
# [11] "response"         "RT"               "correctness"      "gender"           "age"             
# [16] "nativeLanguage"   "levelENlistening" "word"             "count.per.mil"    "X2log"           
# [21] "wavduration"      "vowel.duration"   "lag"              "correctPrime"     "RTprime"         
# [26] "reduced_prime"    "RTprev"           "score_lextale"    "stimtype"         "prime.target"    
# [31] "condition"   



exclude = c("Cs13", "Ns2","Ns7","Ns13","Ns56","Ms11","Ms12","Ms13","Ms14","Ms32", "Ms68") # excluded a priori because of:
# deviant nativeLanguage = Cs13, Ns13
# experimental error/technical issues (e.g. ran without headphones) = Ns2, Ns7, Ns56, Ms11, Ms12, Ms13, Ms14
# reported hearing issues = Ms32, Ms68
d1 = d[!is.element(d$subject, exclude),]
d1=droplevels(d1)


# zoom into the correct subset
d2=d1[d1$sub_experiment=="auditoryLD" & (d1$stimtype=="ld_experimental_real" | d1$stimtype=="ld_experimental_pseudo"),]
d2=droplevels(d2)
# exclude these participants and this word because exceeding 2.5 sd from grand mean
d3=d2[d2$subject!="Ms29"&d2$subject!="Ms34"&d2$subject!="Ms36",]
d4=d3[d3$word!="saloon",]

# non-repeated targets have lag==NA

dd10 = d4[(d4$lexdec_part=="ld_part1") | (d4$lexdec_part=="ld_part2" & !is.na(d4$lag)), ]
dd11 = dd10[dd10$correctness=="correct",] # 8613 kept out of 9763
dd12 = dd11[!is.na(dd11$lexdec_part),] # 8613 kept, 5651 part1, 2962 part2

dd12$RTprevN = as.numeric(as.character(dd12$RTprev))
dd13 = dd12[(300 < dd12$RT) & (dd12$RT < 1900) & (300 < dd12$RTprevN) & (dd12$RTprevN < 1900),] # 7976 kept
dd13$logRT = log(dd13$RT)
dd13$logRTprev = log(dd13$RTprevN)
dd13$logwavduration = log(dd13$wavduration) # here this predictor is numerical


dd13b = dd13

dd13b$early = 1/(1+exp(1*(dd13b$trial-71))) # a non-binary predictor such that early trials have values close to 1 and late trials close to 0

dd13b$lexdec_part_real = (dd13b$lexdec_part == "ld_part1")+0
dd13b$lexdec_part_early = resid(lm(lexdec_part_real ~ early, data=dd13b))

m1 = lmer(logRT ~  early + lexdec_part_early + logRTprev + logwavduration + (1|word) + (1|subject), data=dd13b, REML=F)

#summary(m1)


Random effects:
 Groups   Name        Variance Std.Dev.
 subject  (Intercept) 0.014619 0.12091 
 word     (Intercept) 0.007489 0.08654 
 Residual             0.029406 0.17148 
Number of obs: 7691, groups:  subject, 111; word, 89

Fixed effects:
                  Estimate Std. Error t value
(Intercept)       5.464766   0.173400  31.515
early             0.082606   0.005166  15.989
lexdec_part_early 0.058578   0.216051   0.271 < no additional effect
logRTprev         0.118578   0.009929  11.942
logwavduration    0.100336   0.025235   3.976








#### RT ANALYSIS ######

# start from d4 (= targets only; pp + word with too many errors excluded)
d5=d4[d4$correctness=="correct"&d4$correctPrime=="correct",] # only correct targets + whose prime was also correct

# percentage of data excluded
round(100*(nrow(d4)-nrow(d5))/nrow(d4)) # 14%
a=setdiffDF(d4, d5)
summary(a$nativeLanguage)
# dutch english spanish 
# 138      87     222 

# prep data for analysis
d6=d5[d5$RTprev!="0",]
d7=d6[d6$RT>0,]
d8=d7[d7$RTprime>0,]
d8$RTprev = as.numeric(as.character(d8$RTprev))
d8$logRTprev = log(d8$RTprev) 
d8$logRT = log(d8$RT)
d8$logRTprime = log(d8$RTprime)    
d8$logwavduration = log(d8$wavduration)  
d9=d8[d8$logRT<mean(d8$logRT)+2.5*sd(d8$logRT)&d8$logRT>mean(d8$logRT)-2.5*sd(d8$logRT),] 
round(100*(nrow(d8)-nrow(d9))/nrow(d8))
# [1] 3   % of data considered outlier & removed
a=setdiffDF(d8, d9)
summary(a$nativeLanguage)
# dutch english spanish 
# 34       7      34 
summary(d9$RT)
# Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 536.0   771.0   879.0   917.4  1012.8  1679.0 
round(sd(d9$RT))
#[1]   205

d9$nativeLanguage=relevel(d9$nativeLanguage, "english")
d9$groupcontrast=d9$nativeLanguage
d9 = droplevels(d9)
contrasts(d9$groupcontrast) = rbind(c(2/3, 0), c(-1/3, 1/2), c(-1/3, -1/2)) 
contrasts(d9$groupcontrast)
#               [,1] [,2]
# english  0.6666667  0.0
# dutch   -0.3333333  0.5
# spanish -0.3333333 -0.5
d9$condition=relevel(d9$condition, "variant_mismatch")

### final RT model (in paper, Table 2)
d9.lmer2 = lmer(logRT ~   condition * groupcontrast +  logRTprime + (1|word) + (1|subject), data= d9, REML=F)
d9.lmer2a = lmer(logRT~   condition * groupcontrast +  logRTprime + (1|word) + (1|subject), data=d9[abs(scale(resid(d9.lmer2))) < 2.5,], REML=F)
# Random effects:
#   Groups   Name        Variance Std.Dev.
# subject  (Intercept) 0.008553 0.09248 
# word     (Intercept) 0.002813 0.05304 
# Residual             0.019360 0.13914 
# Number of obs: 2624, groups:  subject, 111; word, 29
# 
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)                            5.65070    0.10051  56.222
# conditionvariant_match                -0.01095    0.00552  -1.983
# groupcontrast1                        -0.09863    0.02082  -4.738
# groupcontrast2                        -0.10107    0.02315  -4.366
# logRTprime                             0.16588    0.01435  11.560
# conditionvariant_match:groupcontrast1  0.03724    0.01162   3.205
# conditionvariant_match:groupcontrast2  0.02967    0.01349   2.200


####### additional model with RTprev:

# first we redo the preamble


library(lme4)


d=read.table('ds_EXP2_reduction.txt',T)
exclude = c("Cs13", "Ns2","Ns7","Ns13","Ns56","Ms11","Ms12","Ms13","Ms14","Ms32", "Ms68") # excluded a priori because of:
# deviant nativeLanguage = Cs13, Ns13 # experimental error/technical issues (e.g. ran without headphones) = Ns2, Ns7, Ns56, Ms11, Ms12, Ms13, Ms14 # reported hearing issues = Ms32, Ms68
d1 = d[!is.element(d$subject, exclude),]
d1=droplevels(d1)
d2=d1[d1$sub_experiment=="auditoryLD"&d1$stimtype=="ld_experimental_real"&d1$prime.target=="target",]
d2=droplevels(d2) 
d3=d2[d2$subject!="Ms29"&d2$subject!="Ms34"&d2$subject!="Ms36",]
d4=d3[d3$word!="saloon",]

# start from d4 (= targets only; pp + word with too many errors excluded)
d5=d4[d4$correctness=="correct"&d4$correctPrime=="correct",] # only correct targets + whose prime was also correct
d5$condition=relevel(d5$condition, 'variant_mismatch')

# prep data for analysis
d6=d5[d5$RTprev!="0",]
d7=d6[d6$RT>0,]
d8=d7[d7$RTprime>0,]
d8$RTprev = as.numeric(as.character(d8$RTprev))
d8$logRTprev = log(d8$RTprev) 
d8$logRT = log(d8$RT)
d8$logRTprime = log(d8$RTprime)    
d8$logwavduration = log(d8$wavduration)  
d9=d8[d8$logRT<mean(d8$logRT)+2.5*sd(d8$logRT)&d8$logRT>mean(d8$logRT)-2.5*sd(d8$logRT),] 

d9$nativeLanguage=relevel(d9$nativeLanguage, "english")
d9$groupcontrast=d9$nativeLanguage
d9 = droplevels(d9)
contrasts(d9$groupcontrast) = rbind(c(2/3, 0), c(-1/3, 1/2), c(-1/3, -1/2)) 


d9.lmer2 = lmer(logRT ~   condition * groupcontrast +  logRTprime + (1|word) + (1|subject), data= d9, REML=F)
d9.lmer2a = lmer(logRT~   condition * groupcontrast +  logRTprime + (1|word) + (1|subject), data=d9[abs(scale(resid(d9.lmer2))) < 2.5,], REML=F)

Groups   Name        Variance Std.Dev.
 subject  (Intercept) 0.008553 0.09248 
 word     (Intercept) 0.002813 0.05304 
 Residual             0.019360 0.13914 
Number of obs: 2624, groups:  subject, 111; word, 29

Fixed effects:
                                      Estimate Std. Error t value
(Intercept)                            5.65070    0.10051  56.222
conditionvariant_match                -0.01095    0.00552  -1.983
groupcontrast1                        -0.09863    0.02082  -4.738
groupcontrast2                        -0.10107    0.02315  -4.366
logRTprime                             0.16588    0.01435  11.560
conditionvariant_match:groupcontrast1  0.03724    0.01162   3.205
conditionvariant_match:groupcontrast2  0.02967    0.01349   2.200


# with logprevRT
d9.lmer2A = lmer(logRT ~   condition * groupcontrast + logRTprev + logRTprime + (1|word) + (1|subject), data= d9, REML=F)
d9.lmer2aA = lmer(logRT~   condition * groupcontrast + logRTprev + logRTprime + (1|word) + (1|subject), data=d9[abs(scale(resid(d9.lmer2))) < 2.5,], REML=F)

Random effects:
 Groups   Name        Variance Std.Dev.
 subject  (Intercept) 0.007199 0.08485 
 word     (Intercept) 0.002723 0.05218 
 Residual             0.019243 0.13872 
Number of obs: 2624, groups:  subject, 111; word, 29

Fixed effects:
                                       Estimate Std. Error t value
(Intercept)                            5.215485   0.121994  42.752
conditionvariant_match                -0.011090   0.005502  -2.015
groupcontrast1                        -0.086945   0.019468  -4.466
groupcontrast2                        -0.091019   0.021626  -4.209
logRTprev                              0.064419   0.010954   5.881
logRTprime                             0.163791   0.014283  11.468
conditionvariant_match:groupcontrast1  0.036887   0.011585   3.184
conditionvariant_match:groupcontrast2  0.029651   0.013444   2.205

####### end of additional model

d9$condition_rel=relevel(d9$condition, 'variant_match')
d9.lmer2_rel = lmer(logRT ~   condition_rel * groupcontrast +  logRTprime + (1|word) + (1|subject), data= d9, REML=F)
d9.lmer2a_rel = lmer(logRT~   condition_rel * groupcontrast +  logRTprime + (1|word) + (1|subject), data=d9[abs(scale(resid(d9.lmer2))) < 2.5,], REML=F)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)                            5.65070    0.10051  56.222
# conditionvariant_match                -0.01095    0.00552  -1.983
# groupcontrast1                        -0.09863    0.02082  -4.738
# groupcontrast2                        -0.10107    0.02315  -4.366
# logRTprime                             0.16588    0.01435  11.560
# conditionvariant_match:groupcontrast1  0.03724    0.01162   3.205
# conditionvariant_match:groupcontrast2  0.02967    0.01349   2.200

### split according to the two statistically significant group contrasts

### contrast 1 (native vs. non=native) (in-text)
## natives
dn = d9[d9$nativeLanguage=="english",]
dn.lmer3 = lmer(logRT ~   condition  +  logRTprime + (1|word) + (1|subject), data= dn, REML=F)
dn.lmer3a = lmer(logRT~   condition  +  logRTprime + (1|word) + (1|subject), data=dn[abs(scale(resid(dn.lmer3))) < 2.5,], REML=F)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)            6.088696   0.187392  32.492
# conditionvariant_match 0.012043   0.008519   1.414 (in-text Results and Discussion in Exp 2)
# logRTprime             0.092004   0.027241   3.377

## non-natives
dnn = d9[d9$nativeLanguage!="english",]
dnn.lmer3 = lmer(logRT ~   condition  +  logRTprime + (1|word) + (1|subject), data= dnn, REML=F) 
dnn.lmer3a = lmer(logRT~   condition  +  logRTprime + (1|word) + (1|subject), data=dnn[abs(scale(resid(dnn.lmer3))) < 2.5,], REML=F)
summary(dnn.lmer3a)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)             5.56236    0.12065  46.103
# conditionvariant_match -0.02103    0.00698  -3.013 (in-text Results and Discussion Exp 2))
# logRTprime              0.18310    0.01711  10.703

#### contrast 2
## Dutch
dnl = d9[d9$nativeLanguage=="dutch",]
dnl.lmer3 = lmer(logRT ~   condition  +  logRTprime + (1|word) + (1|subject), data= dnl, REML=F) 
dnl.lmer3a = lmer(logRT~   condition  +  logRTprime + (1|word) + (1|subject), data=dnl[abs(scale(resid(dnl.lmer3))) < 2.5,], REML=F)
summary(dnl.lmer3a)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)             5.686747   0.163075  34.872
# conditionvariant_match -0.008579   0.008633  -0.994 (in-text)
# logRTprime              0.158002   0.023378   6.759

## Spanish
dsp = d9[d9$nativeLanguage=="spanish",]
dsp.lmer3 = lmer(logRT ~   condition  +  logRTprime + (1|word) + (1|subject), data= dsp, REML=F) 
dsp.lmer3a = lmer(logRT~   condition  +  logRTprime + (1|word) + (1|subject), data=dsp[abs(scale(resid(dsp.lmer3))) < 2.5,], REML=F)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)             5.60205    0.17950  31.210
# conditionvariant_match -0.03425    0.01103  -3.106 (in-text)
# logRTprime              0.18497    0.02528   7.317

### slopes on final model (full data set)
# group by word: convergence error
d9.lmer5 = lmer(logRT ~   condition * groupcontrast +  logRTprime + (1|word) + (0+groupcontrast|word) + (1|subject), data= d9, REML=F) 

# match by word: convergence error
d9.lmer5 = lmer(logRT ~   condition * groupcontrast +  logRTprime + (1|word) + (0+condition|word) + (1|subject), data= d9, REML=F) 

# match by pp: perfect correlation
d9.lmer5  = lmer(logRT ~   condition * groupcontrast +  logRTprime + (1|word) + (0+condition|subject) + (1|subject), data= d9, REML=F)
# Random effects:
#   Groups    Name                      Variance  Std.Dev. Corr
# subject   (Intercept)               2.591e-07 0.000509     
# subject.1 conditionvariant_mismatch 8.237e-03 0.090760     
#           conditionvariant_match    7.914e-03 0.088962 1.00 ***
# word      (Intercept)               2.599e-03 0.050977     
# Residual                            2.536e-02 0.159247     

### competing RT model
d9.lmer3 =  lmer(logRT~ condition * groupcontrast + logRTprev + logRTprime + logwavduration + X2log + trial + lag + (1|word) + (1|subject), data=d9, REML=F)
d9.lmer3a = lmer(logRT~ condition * groupcontrast + logRTprev + logRTprime + logwavduration + X2log + trial + lag + (1|word) + (1|subject), data=d9[abs(scale(resid(d9.lmer3))) < 2.5,], REML=F)
# Random effects:
#   Groups   Name        Variance Std.Dev.
# subject  (Intercept) 0.007177 0.08472 
# word     (Intercept) 0.002744 0.05238 
# Residual             0.019305 0.13894 
# Number of obs: 2626, groups:  subject, 111; word, 29
# 
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)                            4.7734205  0.5104231   9.352
# conditionvariant_match                -0.0100256  0.0055134  -1.818
# groupcontrast1                        -0.0852708  0.0194542  -4.383
# groupcontrast2                        -0.0891911  0.0216124  -4.127
# logRTprev                              0.0701362  0.0109509   6.405
# logRTprime                             0.1633277  0.0143348  11.394
# logwavduration                         0.0668932  0.0779090   0.859
# X2log                                 -0.0016573  0.0053914  -0.307
# trial                                  0.0001639  0.0002062   0.795
# lag                                   -0.0003398  0.0001837  -1.850
# conditionvariant_match:groupcontrast1  0.0348866  0.0116012   3.007
# conditionvariant_match:groupcontrast2  0.0276165  0.0134629   2.051

d9.lmer3_r =  lmer(logRT~ condition_rel * groupcontrast + logRTprev + logRTprime + logwavduration + X2log + trial + lag + (1|word) + (1|subject), data=d9, REML=F)
d9.lmer3a_r = lmer(logRT~ condition_rel * groupcontrast + logRTprev + logRTprime + logwavduration + X2log + trial + lag + (1|word) + (1|subject), data=d9[abs(scale(resid(d9.lmer3))) < 2.5,], REML=F)
summary(d9.lmer3a_r)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)                                   4.7633948  0.5104055   9.333
# condition_relvariant_mismatch                 0.0100256  0.0055134   1.818
# groupcontrast1                               -0.0503841  0.0195099  -2.582
# groupcontrast2                               -0.0615747  0.0217482  -2.831
# logRTprev                                     0.0701362  0.0109509   6.405
# logRTprime                                    0.1633277  0.0143348  11.394
# logwavduration                                0.0668932  0.0779090   0.859
# X2log                                        -0.0016573  0.0053914  -0.307
# trial                                         0.0001639  0.0002062   0.795
# lag                                          -0.0003398  0.0001837  -1.850
# condition_relvariant_mismatch:groupcontrast1 -0.0348866  0.0116012  -3.007
# condition_relvariant_mismatch:groupcontrast2 -0.0276165  0.0134629  -2.051

### additional RT analysis: cognates
# Dutch
cognateD=c("balloon","banana","career", "cassette", "cement", "committee", 
           "debate", "defect","defence","domain","guitar","machine","parade",
           "police","safari","salami","saloon","tobacco","tomato")
d9$cognateD=F
d9[is.element(d9$word, cognateD),]$cognateD=T
du=d9[d9$nativeLanguage=="dutch",]
du.lmer2 = lmer(logRT ~   condition * cognateD +  logRTprime + (1|word) + (1|subject), data=du, REML=F)
du.lmer2a = lmer(logRT~   condition * cognateD +  logRTprime + (1|word) + (1|subject), data=du[abs(scale(resid(du.lmer2))) < 2.5,], REML=F)
# Fixed effects: (in-text)
#                                     Estimate Std. Error t value
# (Intercept)                          5.6881032  0.1648251  34.510
# conditionvariant_match               0.0004662  0.0137630   0.034
# cognateDTRUE                        -0.0057194  0.0269290  -0.212
# logRTprime                           0.1583082  0.0235865   6.712
# conditionvariant_match:cognateDTRUE -0.0134932  0.0178413  -0.756

cognateSP=c("career", "cassette", "cement","collapse","committee", 
            "debate","decline", "defect","defence","design","divorce","domain","guitar","machine","parade",
            "police","potato","safari","salami","saloon","surprise","tobacco","tomato")
d9$cognateSP=F
d9[is.element(d9$word, cognateSP),]$cognateSP=T
sp=d9[d9$nativeLanguage=="spanish",]
sp.lmer2 = lmer(logRT ~   condition * cognateSP +  logRTprime + (1|word) + (1|subject), data=sp, REML=F)
sp.lmer2a = lmer(logRT~   condition * cognateSP +  logRTprime + (1|word) + (1|subject), data=sp[abs(scale(resid(sp.lmer2))) < 2.5,], REML=F)
# Fixed effects:
#                                     Estimate Std. Error t value
# (Intercept)                           5.5518867  0.1830700  30.327
# conditionvariant_match               -0.0002355  0.0217921  -0.011
# cognateSPTRUE                         0.0377503  0.0295489   1.278
# logRTprime                            0.1883297  0.0256162   7.352
# conditionvariant_match:cognateSPTRUE -0.0452730  0.0253823  -1.784

### additional RT analysis: proficiency
cl=d9[d9$nativeLanguage=="english"|d9$nativeLanguage=="dutch"&d9$score_lextale<=85|d9$nativeLanguage=="spanish"&d9$score_lextale>=55,]

# run final model on this set
cl.lmer2  = lmer(logRT ~  condition * groupcontrast +  logRTprime + (1|word) + (1|subject), data=cl, REML=F)
cl.lmer2a = lmer(logRT~   condition * groupcontrast +  logRTprime + (1|word) + (1|subject), data=cl[abs(scale(resid(cl.lmer2))) < 2.5,], REML=F)
# convergence failure; simplify final model by getting rid of control predictor logRTprime
cl.lmer3 = lmer(logRT ~   condition * groupcontrast +   (1|word) + (1|subject), data=cl, REML=F)
cl.lmer3a = lmer(logRT~   condition * groupcontrast +   (1|word) + (1|subject), data=cl[abs(scale(resid(cl.lmer3))) < 2.5,], REML=F)
# Fixed effects:
#   Estimate Std. Error t value
# (Intercept)                            6.802012   0.016184 420.295
# conditionvariant_match                -0.014021   0.005878  -2.385
# groupcontrast1                        -0.123389   0.023927  -5.157
# groupcontrast2                        -0.121990   0.028052  -4.349
# conditionvariant_match:groupcontrast1  0.040357   0.012068   3.344
# conditionvariant_match:groupcontrast2  0.039093   0.014742   2.652


#### barplots RTs
library(ggplot2)
library(gridExtra)
library(ggpubr)

levels(d9$nativeLanguage) # "english" "dutch"   "spanish"
levels(d9$nativeLanguage)c("English","Dutch", "Spanish")
levels(d9$condition) # [1] "variant_mismatch" "variant_match" 
levels(d9$condition)=c("Variant mismatch","Variant match")

d9$condition=relevel(d9$condition, "Variant match")

d9a <- summarySEwithin(d9, measurevar="RT", withinvars=c("nativeLanguage","condition"), idvar="subject")
d9a
# nativeLanguage        condition   N        RT  RT_norm       sd        se       ci
# 1          Dutch    Variant match 482  895.9440 910.1681 179.5928  8.180228 16.07340
# 2          Dutch Variant mismatch 502  909.1992 924.4245 186.7504  8.335076 16.37601
# 3        English    Variant match 437  860.7140 923.1485 158.0463  7.560380 14.85932
# 4        English Variant mismatch 452  851.6128 911.9232 161.5321  7.597831 14.93155
# 5        spanish    Variant match 388  980.3660 894.2705 192.2385  9.759432 19.18814
# 6        spanish Variant mismatch 425 1022.4494 938.5946 218.1551 10.582076 20.79986

pl2<- ggplot(d9a, aes(x=nativeLanguage, y=RT,fill=condition)) + 
  geom_bar(stat="identity",color="black",
           position=position_dodge(), size=0.75) +
  geom_errorbar(aes(ymin=RT-ci, ymax=RT+ci), width=.2,
                position=position_dodge(.9),size=0.75) 
scale_fill_grey() 
print(pl2)
pl2 = ggpar(pl2, palette="grey",size=2,main="", ylab="Target RT (ms)", xlab="Native language", ylim=c(500,1050), legend="right", legend.title="", font.legend=c(14, "black"), 
            font.x=16, font.y=16, font.tickslab=14, ggtheme=theme_minimal())
pl2


### condition is WITHIN pp variable
# so SE from mean must also be calculated as such
# see http://www.cookbook-r.com/Graphs/Plotting_means_and_error_bars_(ggplot2)/


############# HELPER FUNCTIONS
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}




normDataWithin <- function(data=NULL, idvar, measurevar, betweenvars=NULL,
                           na.rm=FALSE, .drop=TRUE) {
  library(plyr)
  
  # Measure var on left, idvar + between vars on right of formula.
  data.subjMean <- ddply(data, c(idvar, betweenvars), .drop=.drop,
                         .fun = function(xx, col, na.rm) {
                           c(subjMean = mean(xx[,col], na.rm=na.rm))
                         },
                         measurevar,
                         na.rm
  )
  
  # Put the subject means with original data
  data <- merge(data, data.subjMean)
  
  # Get the normalized data in a new column
  measureNormedVar <- paste(measurevar, "_norm", sep="")
  data[,measureNormedVar] <- data[,measurevar] - data[,"subjMean"] +
    mean(data[,measurevar], na.rm=na.rm)
  
  # Remove this subject mean column
  data$subjMean <- NULL
  
  return(data)
}


summarySEwithin <- function(data=NULL, measurevar, betweenvars=NULL, withinvars=NULL,
                            idvar=NULL, na.rm=FALSE, conf.interval=.95, .drop=TRUE) {
  
  # Ensure that the betweenvars and withinvars are factors
  factorvars <- vapply(data[, c(betweenvars, withinvars), drop=FALSE],
                       FUN=is.factor, FUN.VALUE=logical(1))
  
  if (!all(factorvars)) {
    nonfactorvars <- names(factorvars)[!factorvars]
    message("Automatically converting the following non-factors to factors: ",
            paste(nonfactorvars, collapse = ", "))
    data[nonfactorvars] <- lapply(data[nonfactorvars], factor)
  }
  
  # Get the means from the un-normed data
  datac <- summarySE(data, measurevar, groupvars=c(betweenvars, withinvars),
                     na.rm=na.rm, conf.interval=conf.interval, .drop=.drop)
  
  # Drop all the unused columns (these will be calculated with normed data)
  datac$sd <- NULL
  datac$se <- NULL
  datac$ci <- NULL
  
  # Norm each subject's data
  ndata <- normDataWithin(data, idvar, measurevar, betweenvars, na.rm, .drop=.drop)
  
  # This is the name of the new column
  measurevar_n <- paste(measurevar, "_norm", sep="")
  
  # Collapse the normed data - now we can treat between and within vars the same
  ndatac <- summarySE(ndata, measurevar_n, groupvars=c(betweenvars, withinvars),
                      na.rm=na.rm, conf.interval=conf.interval, .drop=.drop)
  
  # Apply correction from Morey (2008) to the standard error and confidence interval
  #  Get the product of the number of conditions of within-S variables
  nWithinGroups    <- prod(vapply(ndatac[,withinvars, drop=FALSE], FUN=nlevels,
                                  FUN.VALUE=numeric(1)))
  correctionFactor <- sqrt( nWithinGroups / (nWithinGroups-1) )
  
  # Apply the correction factor
  ndatac$sd <- ndatac$sd * correctionFactor
  ndatac$se <- ndatac$se * correctionFactor
  ndatac$ci <- ndatac$ci * correctionFactor
  
  # Combine the un-normed means with the normed results
  merge(datac, ndatac)
}